==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkInteractorStyleAreaSelectHover.java <==
// java wrapper for vtkInteractorStyleAreaSelectHover object
//

package vtk;
import vtk.*;

public class vtkInteractorStyleAreaSelectHover extends vtkInteractorStyleRubberBand2D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLayout_2(vtkAreaLayout id0);
  public void SetLayout(vtkAreaLayout id0)
    { SetLayout_2(id0); }

  private native long GetLayout_3();
  public vtkAreaLayout GetLayout() {
    long temp = GetLayout_3();

    if (temp == 0) return null;
    return (vtkAreaLayout)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelField_4(String id0);
  public void SetLabelField(String id0)
    { SetLabelField_4(id0); }

  private native String GetLabelField_5();
  public String GetLabelField()
    { return GetLabelField_5(); }

  private native void SetUseRectangularCoordinates_6(boolean id0);
  public void SetUseRectangularCoordinates(boolean id0)
    { SetUseRectangularCoordinates_6(id0); }

  private native boolean GetUseRectangularCoordinates_7();
  public boolean GetUseRectangularCoordinates()
    { return GetUseRectangularCoordinates_7(); }

  private native void UseRectangularCoordinatesOn_8();
  public void UseRectangularCoordinatesOn()
    { UseRectangularCoordinatesOn_8(); }

  private native void UseRectangularCoordinatesOff_9();
  public void UseRectangularCoordinatesOff()
    { UseRectangularCoordinatesOff_9(); }

  private native void OnMouseMove_10();
  public void OnMouseMove()
    { OnMouseMove_10(); }

  private native void SetInteractor_11(vtkRenderWindowInteractor id0);
  public void SetInteractor(vtkRenderWindowInteractor id0)
    { SetInteractor_11(id0); }

  private native void SetHighLightColor_12(double id0,double id1,double id2);
  public void SetHighLightColor(double id0,double id1,double id2)
    { SetHighLightColor_12(id0,id1,id2); }

  private native void SetHighLightWidth_13(double id0);
  public void SetHighLightWidth(double id0)
    { SetHighLightWidth_13(id0); }

  private native double GetHighLightWidth_14();
  public double GetHighLightWidth()
    { return GetHighLightWidth_14(); }

  private native int GetIdAtPos_15(int id0,int id1);
  public int GetIdAtPos(int id0,int id1)
    { return GetIdAtPos_15(id0,id1); }

  public vtkInteractorStyleAreaSelectHover() { super(); }

  public vtkInteractorStyleAreaSelectHover(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-19-armv7h.pkg.tar.xz: vtk/vtkInteractorStyleAreaSelectHover.java <==
// java wrapper for vtkInteractorStyleAreaSelectHover object
//

package vtk;
import vtk.*;

public class vtkInteractorStyleAreaSelectHover extends vtkInteractorStyleRubberBand2D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLayout_2(vtkAreaLayout id0);
  public void SetLayout(vtkAreaLayout id0)
    { SetLayout_2(id0); }

  private native long GetLayout_3();
  public vtkAreaLayout GetLayout() {
    long temp = GetLayout_3();

    if (temp == 0) return null;
    return (vtkAreaLayout)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabelField_4(String id0);
  public void SetLabelField(String id0)
    { SetLabelField_4(id0); }

  private native String GetLabelField_5();
  public String GetLabelField()
    { return GetLabelField_5(); }

  private native void SetUseRectangularCoordinates_6(boolean id0);
  public void SetUseRectangularCoordinates(boolean id0)
    { SetUseRectangularCoordinates_6(id0); }

  private native boolean GetUseRectangularCoordinates_7();
  public boolean GetUseRectangularCoordinates()
    { return GetUseRectangularCoordinates_7(); }

  private native void UseRectangularCoordinatesOn_8();
  public void UseRectangularCoordinatesOn()
    { UseRectangularCoordinatesOn_8(); }

  private native void UseRectangularCoordinatesOff_9();
  public void UseRectangularCoordinatesOff()
    { UseRectangularCoordinatesOff_9(); }

  private native void OnMouseMove_10();
  public void OnMouseMove()
    { OnMouseMove_10(); }

  private native void SetInteractor_11(vtkRenderWindowInteractor id0);
  public void SetInteractor(vtkRenderWindowInteractor id0)
    { SetInteractor_11(id0); }

  private native void SetHighLightColor_12(double id0,double id1,double id2);
  public void SetHighLightColor(double id0,double id1,double id2)
    { SetHighLightColor_12(id0,id1,id2); }

  private native void SetHighLightWidth_13(double id0);
  public void SetHighLightWidth(double id0)
    { SetHighLightWidth_13(id0); }

  private native double GetHighLightWidth_14();
  public double GetHighLightWidth()
    { return GetHighLightWidth_14(); }

  private native int GetIdAtPos_15(int id0,int id1);
  public int GetIdAtPos(int id0,int id1)
    { return GetIdAtPos_15(id0,id1); }

  public vtkInteractorStyleAreaSelectHover() { super(); }

  public vtkInteractorStyleAreaSelectHover(long id) { super(id); }
  public native long   VTKInit();

}
